package vehicle.part.gearbox;

import vehicle.part.engine.Engine;
import vehicle.part.engine.EngineBrokenException;

public class GearBoxManual implements GearBox{

    private Gear currentGear;
    private Gear maxGear;
    private Boolean engaged;

    /**
     * Constructor
     * @param maxGear
     */
    public GearBoxManual(Gear maxGear) {
        this.maxGear = maxGear;
        this.currentGear = Gear.NEUTRAL;
        this.engaged = false;
    }

    /**
     * Method to gear up
     * @throws StallException
     */
    @Override
    public void gearUp() throws StallException{
        if(engaged) {
            if (!currentGear.equals(maxGear)) {
                currentGear = Gear.getEnum(currentGear.getValue() + 1);
            }
        }
        else
            throw new StallException();
    }

    /**
     * Method to gear down
     * @throws StallException
     */
    @Override
    public void gearDown() throws StallException{
        if(engaged) {
            if (!currentGear.equals(Gear.REVERSE)) {
                currentGear = Gear.getEnum(currentGear.getValue() - 1);
            }
        }
        else
            throw new StallException();
    }

    /**
     * Go to neutral gear
     * @throws StallException
     */
    @Override
    public void neutral() throws StallException{
        if(engaged) {
            currentGear = Gear.NEUTRAL;
        }
        else
            throw new StallException();
    }

    /**
     * Go to reverse gear
     * @throws StallException
     * @throws EngineBrokenException
     */
    @Override
    public void reverse() throws StallException, EngineBrokenException {
        if(engaged) {
            // TODO Récupérer la vitesse de la voiture pour savoir si le moteur casse
            if(true) {
                currentGear = Gear.REVERSE;
            }else{
                throw new EngineBrokenException();
            }
        }
        else
            throw new StallException();

    }

    /**
     * Engage
     */
    public void engage(){
        engaged = true;
    }

    /**
     * Disengage
     */
    public void disengage(){
        engaged = false;
    }
}
